@@ -7,7 +7,7 @@ import pytest
 import pytz
 
 import timely_beliefs as tb
-from timely_beliefs.examples import get_example_df
+from timely_beliefs.examples import get_example_df, get_examples_path
 from timely_beliefs.tests.utils import assert_metadata_is_retained
 
 
@@ -20,8 +20,22 @@ def csv_file(tmpdir_factory):
     os.remove("test.csv")
 
 
+@pytest.fixture(scope="module")
+def csv_nat_file(tmpdir_factory):
+    """Save BeliefsDataFrame to csv, after including a NaT value."""
+
+    df = get_example_df().reset_index()
+    df.iloc[0, 1] = pd.NaT
+    df = df.set_index(
+        ["event_start", "belief_time", "source", "cumulative_probability"]
+    )
+    df.to_csv("test_NaT.csv")
+    yield
+    os.remove("test_NaT.csv")
+
+
 def test_load_beliefs(csv_file):
-    """Test loading BeliefsDataFrame to csv.
+    """Test loading BeliefsDataFrame from csv.
     The saved file does not contain the sensor information, and the sources are saved by their name.
     Therefore, we test the following functionality:
     - The user should specify the sensor upon loading
@@ -29,7 +43,7 @@ def test_load_beliefs(csv_file):
     - The user should have the possibility to look up the saved source names by passing a list of sources.
     """
 
-    # Load beliefs with tb.read_csv
+    # Load beliefs with pd.read_csv
     df = pd.read_csv("test.csv")
     df_copy = df.copy()
     with pytest.warns(UserWarning, match="created"):
@@ -40,6 +54,7 @@ def test_load_beliefs(csv_file):
     # GH 34
     pd.testing.assert_frame_equal(df, df_copy)
 
+    # Now load beliefs with tb.read_csv
     # No lookup should issue warning
     with pytest.warns(UserWarning, match="looking them up"):
         bdf = tb.read_csv("test.csv", sensor=tb.Sensor("Sensor Y"))
@@ -69,6 +84,80 @@ def test_load_beliefs(csv_file):
     assert isinstance(bdf.index.get_level_values("belief_time")[0], datetime)
 
 
+def test_load_beliefs_with_nat_values(csv_nat_file):
+    """Test loading BeliefsDataFrame from csv containing one NaT belief_time value.
+
+    The NaT value is an empty cell in the belief time column.
+    The relevant row should be skipped, as requested using the combination of na_values and keep_default_na.
+    """
+
+    # Load beliefs with tb.read_csv
+    df = tb.read_csv(
+        "test_NaT.csv",
+        sensor=tb.Sensor("Sensor Y"),
+        source=tb.BeliefSource("Source A"),
+        timezone="Europe/Amsterdam",
+        na_values=[""],  # tells pd.read_csv to treat empty cells as NaN values
+        keep_default_na=False,
+    )
+    assert len(df) == len(get_example_df()) - 1
+
+
+def test_load_timezone_naive_data():
+    """Test loading timezone naive time series data from csv.
+
+    The test data is around a DST transition that lead to duplicate indices.
+    """
+
+    # Load only datetime and value columns with tb.read_csv
+    sensor = tb.Sensor("Sensor X")
+    source = tb.BeliefSource("Source A")
+    path = os.path.join(get_examples_path(), "timezone_naive_sample.csv")
+    timezone = "Europe/Amsterdam"
+    df = tb.read_csv(
+        path=path,
+        timezone=timezone,
+        sensor=sensor,
+        source=source,
+        belief_horizon=timedelta(0),
+        usecols=["datetime", "value"],
+    )
+    assert len(df.event_starts.unique()) == 6
+
+    # Load also the column describing when the data was recorded
+    df = tb.read_csv(
+        path=path,
+        timezone=timezone,
+        sensor=sensor,
+        source=source,
+        usecols=["datetime", "recorded", "value"],
+    )
+    assert len(df.event_starts.unique()) == 6
+
+    # Reload while filtering by a column that ends up in the BeliefsDataFrame
+    df = tb.read_csv(
+        path=path,
+        timezone=timezone,
+        sensor=sensor,
+        source=source,
+        usecols=["datetime", "recorded", "value"],
+        filter_by_column={"recorded": "2022-10-09 00:00"},
+    )
+    assert len(df.event_starts.unique()) == 5
+
+    # Reload while filtering by a column that does not end up in the BeliefsDataFrame
+    df = tb.read_csv(
+        path=path,
+        timezone=timezone,
+        sensor=sensor,
+        source=source,
+        usecols=["datetime", "recorded", "value"],
+        filter_by_column={"sensor": "X"},
+    )
+    assert len(df.event_starts.unique()) == 5
+    assert "sensor" not in df.columns.names
+
+
 @pytest.mark.parametrize(
     "args, kwargs",
     [
